/**CHeaderFile*****************************************************************

  FileName    [statenode.h]

  PackageName [mc]

  Synopsis    [The header file for the <tt>statenode</tt> data structure.]

  Description [The <tt>statenode</tt> implements a data structure
  to use to manage tree-like annotated counter-examples.]

  Author      [Simon Busard]

  Copyright   [
  This file is part of the ``mc'' package of NuSMV version 2.
  Copyright (C) 1998-2001 by CMU and ITC-irst.

  NuSMV version 2 is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  NuSMV version 2 is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA.

  For more information of NuSMV see <http://nusmv.irst.itc.it>
  or email to <nusmv-users@irst.itc.it>.
  Please report bugs to <nusmv-users@irst.itc.it>.

  To contact the NuSMV development board, email to <nusmv@irst.itc.it>. ]

  Revision    []

******************************************************************************/

#ifndef _statenode_h
#define _statenode_h

#include "mc.h"
#include "mcInt.h"
#include "dd/dd.h"
#include "node/node.h"
#include "util.h"
#include "utils/utils_io.h"

/*---------------------------------------------------------------------------*/
/* Constant declarations                                                     */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* Type declarations                                                         */
/*---------------------------------------------------------------------------*/

typedef node_ptr statenode_ptr;

/*---------------------------------------------------------------------------*/
/* Structure declarations                                                    */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* Macro declarations                                                        */
/*---------------------------------------------------------------------------*/

#define statenode_get_state(_n_) ((bdd_ptr) car(_n_))
#define statenode_set_state(_n_,_s_) node_node_setcar(_n_,((node_ptr) _s_))
#define statenode_get_id(_n_) node_get_int(cdr(_n_))
#define statenode_set_id(_n_,_i_) node_int_setcar(cdr(_n_),_i_)
#define statenode_get_annotation(_n_) car(cdr(cdr(_n_)))
#define statenode_set_annotation(_n_,_a_) node_node_setcar(cdr(cdr(_n_)),_a_)
#define statenode_get_branches(_n_) car(cdr(cdr(cdr(_n_))))
#define statenode_set_branches(_n_,_b_) node_node_setcar(cdr(cdr(cdr(_n_))),_b_)
#define statenode_add_branch(_n_,_b_) node_node_setcar(cdr(cdr(cdr(_n_))),cons(_b_,car(cdr(cdr(cdr(_n_))))))

#define statenode_is_annotated(_n_) (statenode_get_annotation(_n_) != Nil)

/*---------------------------------------------------------------------------*/
/* Function prototypes                                                       */
/*---------------------------------------------------------------------------*/

EXTERN statenode_ptr 	statenode_new ARGS((bdd_ptr));
EXTERN statenode_ptr 	statenode_dup ARGS((statenode_ptr));
EXTERN void 			statenode_free ARGS((statenode_ptr));
EXTERN void 			statenode_free_branch ARGS((node_ptr));

EXTERN void 			statenode_remove_branch ARGS((statenode_ptr,node_ptr));

EXTERN statenode_ptr 	statenode_get_loop ARGS((statenode_ptr));
EXTERN void 			statenode_set_loop ARGS((statenode_ptr,statenode_ptr));

EXTERN boolean 			statenode_satisfies ARGS((statenode_ptr,BddFsm_ptr,BddEnc_ptr,node_ptr,node_ptr));

EXTERN void				statenode_display ARGS((BddFsm_ptr,BddEnc_ptr,statenode_ptr,node_ptr,FILE *));

EXTERN int				statenode_get_state_count ARGS((node_ptr));

#endif /* _statenode_h */
