package counterexample;

/**
 * Counterexample is the internal representation of a counterexample. A
 * counterexample is a list of states, annotated with a specification that the
 * counterexample doesn't satisfy.
 * 
 * @author Simon Busard <simon.busard@uclouvain.be>
 * 
 */

public class Counterexample {

	/**
	 * The list of all states of this counterexample.
	 */
	private State[] states;

	/**
	 * The formula which this is a counterexample.
	 */
	private String specification;

	/**
	 * The initial state of this counterexample.
	 */
	private State initial;

	/**
	 * Creates a new counterexample with specification as the formula the
	 * counterexample violates, initial as the initial state of the
	 * counterexample and states as the set of states of the counterexample.
	 * 
	 * @param specification
	 *            the CTL formula the counterexample violates.
	 * @param initial
	 *            the first state of the counterexample.
	 * @param states
	 *            the set of states the counterexamples contains.
	 */
	public Counterexample(String specification, State initial, State[] states) {
		this.specification = specification;
		this.initial = initial;
		this.states = states;
	}

	/**
	 * @return the set of all states.
	 */
	public State[] getStates() {
		return states;
	}

	/**
	 * @return the specification.
	 */
	public String getSpecification() {
		return specification;
	}

	/**
	 * @return the initial state.
	 */
	public State getInitial() {
		return initial;
	}
}
