package counterexample;

/**
 * Transition is the internal representation of a transition.
 * 
 * A transition is an edge between two states, labeled with a set of
 * variable-value pairs. It contains this set and its source and destination
 * states.
 * 
 * @author Simon Busard <simon.busard@uclouvain.be>
 * 
 */

public class Transition {

	/**
	 * The list of input-value pairs of this transition.
	 */
	private Value[] inputs;

	/**
	 * The source state of this transition.
	 */
	private State from;

	/**
	 * The destination state of this transition.
	 */
	private State to;

	/**
	 * Creates a new transition from from to to, labeled with inputs.
	 * 
	 * @param inputs
	 *            the list of input-value pairs of the created transition.
	 * @param from
	 *            the source state.
	 * @param to
	 *            the destination state.
	 */
	public Transition(Value[] inputs, State from, State to) {
		this.inputs = inputs;
		this.from = from;
		this.to = to;
	}

	/**
	 * @return the set of variable-value pairs representing the inputs.
	 */
	public Value[] getInputs() {
		return inputs;
	}

	/**
	 * @return the source state.
	 */
	public State getFrom() {
		return from;
	}

	/**
	 * @return the destination state.
	 */
	public State getTo() {
		return to;
	}

}
