package display.graph;

import java.util.HashSet;
import java.util.Set;

import counterexample.Branch;
import counterexample.State;

/**
 * A node is an element of a displayed graph, representing a state.
 * 
 * @author Simon Busard <simon.busard@uclouvain.be>
 * 
 */
public class Node {

	/**
	 * The state represented by this node.
	 */
	private State state;

	/**
	 * The set of branches of state that are currently displayed.
	 */
	private Set<Branch> displayedBranches;

	/**
	 * Creates a new node.
	 * 
	 * @param state
	 *            The state the new node represents.
	 */
	public Node(State state) {
		this.state = state;
		this.displayedBranches = new HashSet<Branch>();
	}

	/**
	 * Returns the state this node represents.
	 * 
	 * @return the state this node represents.
	 */
	public State getState() {
		return this.state;
	}

	/**
	 * Returns whether a given branch is currently displayed or not.
	 * 
	 * @param branch
	 *            a branch starting at the state of this node.
	 * @return true if branch is displayed, false otherwise.
	 */
	public boolean isDisplayed(Branch branch) {
		return this.displayedBranches.contains(branch);
	}

	/**
	 * Sets the display state of branch to displayed.
	 * 
	 * @param branch
	 *            a branch of the state of this node.
	 * @param displayed
	 *            whether or not set the branch as displayed.
	 */
	public void setDisplayed(Branch branch, boolean displayed) {
		if (displayed) {
			this.displayedBranches.add(branch);
		} else {
			this.displayedBranches.remove(branch);
		}
	}
}