package display.gui;

import java.awt.BorderLayout;
import java.util.List;

import javax.swing.JTable;

import counterexample.State;
import counterexample.Value;

/**
 * A table info panel is an info panel displaying information in a table. This
 * info panel doesn't display input variables.
 * 
 * @author Simon Busard <simon.busard@uclouvain.be>
 * 
 */
public class TableInfoPanel extends InfoPanel {

	private static final long serialVersionUID = 1L;

	/*
	 * (non-Javadoc)
	 * 
	 * @see display.gui.InfoPanel#displayStatesInfo(java.util.List)
	 */
	@Override
	protected void displayStatesInfo(List<State> states) {
		this.removeAll();
		if (states.size() > 0) {
			String[] columnNames = new String[states.get(0).getValues().length + 1];
			Value[] values = states.get(0).getValues();
			columnNames[0] = "State id";
			for (int i = 0; i < values.length; i++) {
				columnNames[i + 1] = values[i].getVariable();
			}
			String[][] data = new String[states.size()][columnNames.length];
			for (int i = 0; i < states.size(); i++) {
				data[i][0] = Integer.toString(states.get(i).getId());
				for (int j = 0; j < states.get(i).getValues().length; j++) {
					if (!this.changedVar
							|| i <= 0
							|| getValueFromVariable(states.get(i - 1),
									states.get(i).getValues()[j].getVariable())
									.equals(states.get(i).getValues()[j]
											.getValue())) {
						data[i][j + 1] = states.get(i).getValues()[j]
								.getValue();
					} else {
						data[i][j + 1] = "<html><strong><font color=red>"
							+ states.get(i).getValues()[j].getValue()
							+ "</font></strong></html>";

					}
				}
			}
			JTable table = new JTable(data, columnNames);
			this.setLayout(new BorderLayout());
			this.add(table.getTableHeader(), BorderLayout.NORTH);
			this.add(table, BorderLayout.CENTER);

			this.panel.adjustSplitpane();
		}
	}

	/**
	 * Returns the value of variable of state.
	 * 
	 * @param state
	 *            the state to search.
	 * @param variable
	 *            the variable to search.
	 * @return If state contains a value to the variable variable, returns this
	 *         value, null otherwise.
	 */
	private String getValueFromVariable(State state, String variable) {
		for (Value value : state.getValues()) {
			if (value.getVariable().equals(variable)) {
				return value.getValue();
			}
		}
		return null;
	}
}
