package display.layout;

import util.ExpandableList;
import counterexample.Transition;
import display.graph.Node;

/**
 * The narrow tree like layout layouts a counterexample displaying vertical
 * branches.
 * 
 * @author Simon Busard <simon.busard@uclouvain.be>
 * 
 */
public class NarrowTreeLikeLayout extends TreeLikeLayout implements
		CounterexampleLayout {

	/**
	 * Layouts the intern graph by storing each node location in locations.
	 */
	protected void buildLayout() {
		// Initiate useful lists
		// allDrawn is the list of all already drawn vertices (indices are ids)
		ExpandableList<Node> allDrawn = new ExpandableList<Node>();
		// toDraw is the list of transitions to draw.
		// The transition (and the end vertex if any) will be drawn.
		// Indices are positions at the current stage
		ExpandableList<Transition> toDraw = new ExpandableList<Transition>();
		// toDrawNext keeps the list of transitions to draw at the next stage
		ExpandableList<Transition> toDrawNext = new ExpandableList<Transition>();
		Node node = getNodeFromState(this.graph, counterexample.getInitial());
		drawNode(node, 0, 0);
		allDrawn.set(counterexample.getInitial().getId(), node);
		Transition[] nexts = counterexample.getInitial().getNexts();
		for (Transition trans : nexts) {
			if (getNodeFromState(graph, trans.getTo()) != null) {
				toDraw.add(trans);
			}
		}

		int stage = 1;
		while (!toDraw.isEmpty()) {
			toDrawNext = new ExpandableList<Transition>();

			for (int i = 0; i < toDraw.size(); i++) {
				Transition tr = toDraw.get(i);

				while (toDrawNext.size() < i)
					toDrawNext.add(null);

				if (tr != null) {
					if (allDrawn.get(tr.getTo().getId()) != null) {
						// Loop, nothing to do
					} else {
						// Normal drawing
						node = getNodeFromState(graph, tr.getTo());
						if (node != null) {
							drawNode(node, stage, i);
							allDrawn.set(tr.getTo().getId(), node);
							nexts = tr.getTo().getNexts();
							for (Transition trans : nexts) {
								if (getNodeFromState(graph, trans.getTo()) != null) {
									toDrawNext.add(trans);
								}
							}
						}
					}
				}
			}

			toDraw = toDrawNext;
			stage++;
		}
	}
}
